MopperLocalizations class abstract

Callers can lookup localized strings with an instance of MopperLocalizations returned by MopperLocalizations.of(context).

Applications need to include MopperLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'l10n/mopper_localizations.dart';

return MaterialApp(
  localizationsDelegates: MopperLocalizations.localizationsDelegates,
  supportedLocales: MopperLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the MopperLocalizations.supportedLocales property.

Implementers

Constructors

MopperLocalizations(String locale)

Properties

annotateButton String
Label for the button to start annotating a screenshot
no setter
categoryBug String
Category chip label for bugs
no setter
categoryFeature String
Category chip label for feature requests
no setter
categoryLabel String
Label for the category choice chips
no setter
categoryPerformance String
Category chip label for performance issues
no setter
categoryUiUx String
Category chip label for UI/UX issues
no setter
descriptionHint String
Hint text for the description text field
no setter
descriptionLabel String
Label for the description text field
no setter
descriptionRequired String
Validation error when description field is empty
no setter
discardButton String
Label for the discard button
no setter
doneButton String
Label for the button to finish annotating
no setter
feedbackButtonLabel String
Label for the floating action button that opens the feedback form
no setter
feedbackSubmittedSuccess String
Snackbar message shown when feedback is submitted successfully
no setter
feedbackTitleHint String
Hint text for the feedback title text field
no setter
feedbackTitleLabel String
Label for the optional feedback title text field
no setter
hashCode int
The hash code for this object.
no setterinherited
localeName String
final
requiredBadge String
Badge text shown next to required fields
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotAttached String
Label shown when a screenshot is attached
no setter
submitButton String
Label for the submit feedback button
no setter
submitFeedbackTitle String
Title shown in the app bar of the feedback form
no setter
submittingFeedback String
Loading overlay text shown while feedback is being submitted
no setter
systemDiagnosticsTitle String
Title for the system diagnostics section
no setter
yourNameHint String
Hint text for the name text field
no setter
yourNameLabel String
Label for the optional name text field
no setter

Methods

feedbackSubmittedError(String errors) String
Snackbar message shown when feedback submission fails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) MopperLocalizations?

Constants

delegate → const LocalizationsDelegate<MopperLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.