annotateButton property
String
get
annotateButton
Label for the button to start annotating a screenshot
In en, this message translates to: 'Annotate'
Implementation
String get annotateButton;
Label for the button to start annotating a screenshot
In en, this message translates to: 'Annotate'
String get annotateButton;