descriptionHint property

  1. @override
String get descriptionHint
override

Hint text for the description text field

In en, this message translates to: 'Please describe the steps to reproduce or your specific suggestion...'

Implementation

@override
String get descriptionHint =>
    'Please describe the steps to reproduce or your specific suggestion...';