MopperLocalizationsNl class

The translations for Dutch Flemish (nl).

Inheritance

Constructors

MopperLocalizationsNl([String locale = 'nl'])

Properties

annotateButton String
Label for the button to start annotating a screenshot
no setteroverride
categoryBug String
Category chip label for bugs
no setteroverride
categoryFeature String
Category chip label for feature requests
no setteroverride
categoryLabel String
Label for the category choice chips
no setteroverride
categoryPerformance String
Category chip label for performance issues
no setteroverride
categoryUiUx String
Category chip label for UI/UX issues
no setteroverride
descriptionHint String
Hint text for the description text field
no setteroverride
descriptionLabel String
Label for the description text field
no setteroverride
descriptionRequired String
Validation error when description field is empty
no setteroverride
discardButton String
Label for the discard button
no setteroverride
doneButton String
Label for the button to finish annotating
no setteroverride
feedbackButtonLabel String
Label for the floating action button that opens the feedback form
no setteroverride
feedbackSubmittedSuccess String
Snackbar message shown when feedback is submitted successfully
no setteroverride
feedbackTitleHint String
Hint text for the feedback title text field
no setteroverride
feedbackTitleLabel String
Label for the optional feedback title text field
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
localeName String
finalinherited
requiredBadge String
Badge text shown next to required fields
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotAttached String
Label shown when a screenshot is attached
no setteroverride
submitButton String
Label for the submit feedback button
no setteroverride
submitFeedbackTitle String
Title shown in the app bar of the feedback form
no setteroverride
submittingFeedback String
Loading overlay text shown while feedback is being submitted
no setteroverride
systemDiagnosticsTitle String
Title for the system diagnostics section
no setteroverride
yourNameHint String
Hint text for the name text field
no setteroverride
yourNameLabel String
Label for the optional name text field
no setteroverride

Methods

feedbackSubmittedError(String errors) String
Snackbar message shown when feedback submission fails
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited